@@ -34,14 +34,14 @@ cron.hour().every(4)
 cron2 = tab.new(command='/foo/bar',comment='SomeID')
 cron2.every_reboot()
 
-list = tab.find('bar')
+list = tab.find_command('bar')
 cron3 = list[0]
 cron3.clear()
 cron3.minute().every(1)
 
 print unicode(tab.render())
 
-for cron4 in tab.find('echo'):
+for cron4 in tab.find_command('echo'):
     print cron4
 
 for cron5 in tab:
@@ -55,7 +55,7 @@ t.write()
 import os, re, sys
 import tempfile
 
-__version__ = '0.9'
+__version__ = '0.9.3'
 
 CRONCMD = "/usr/bin/crontab"
 ITEMREX = re.compile('^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)' +
@@ -151,7 +151,10 @@ class CronTab(object):
                     "Ignoring invalid crontab line `%s`\n" % str(cron))
                 continue
             crons.append(unicode(cron))
-        return '\n'.join(crons)
+        result = '\n'.join(crons)
+        if result[-1] not in [ '\n', '\r' ]:
+            result += '\n'
+        return result
 
     def new(self, command='', comment=''):
         """
